import { Server } from "socket.io";
import {TSocket} from "../utilities/Types";
import fs from "fs";
import path from "path";

type Asset = {
    key: string
    value: string
    type: 'base64' | 'link'
}

export default function (socket: TSocket, io: Server) {
    socket.on('assets:download', async (data: any, callback: (response: Asset[]) => void) => {
        console.log('assets:download requested');

        let assets: Asset[] = [];
        const tiles = listTiles();

        tiles.forEach(tile => {
            assets.push({key: tile, value: '/tiles/' + tile, type: 'link'});
        });

        console.log('assets:download response', assets)

        // return the list of assets to the socket
        callback(assets);
    });
}

function listTiles(): string[] {
    // get root path
    const folder = path.join(process.cwd(), 'public', 'tiles');

    // list the files in the folder
    let tiles: string[] = [];

    try {
        const files = fs.readdirSync(folder);

        files.forEach(file => {
            tiles.push(file);
        });
    } catch (err) {
        console.log(err);
    }

    console.log(tiles);

    return tiles;
}